/* ===================================================================
 * Music Spectrum Analyzer and Auto power control of Stereo Amplifier
 * ===================================================================
 * Module: Amplifier.h 
 * Header file for the Amplifier and Analog channel classes
 * ===================================================================
 * By: Zakie Mashiah
 * ===================================================================
 */
#ifndef __Amplifier_h
#define __Amplifier_h

/* Amplifier Class
 * Preseves the state, operate (control) the Amplifier through IR
 */
class AmplifierState
{
	private:

	bool isAmplifierOn;
	bool isNowPlaying;
	unsigned long lastIdle;     // Preserves the millis() read when idle was detected
	unsigned long offIRCommand; // the IR command to turn the amplifier off
	unsigned long onIRCommand;  // the IR command to turn the amplifier on
	unsigned long onIRInput;    // Which input to set after turning amplifier on
	unsigned long idleTimeToTurnOff; // The time to wait to shut down amplifier

	
	public:
	void Init(unsigned long offCommand, unsigned long onCommand, unsigned long onInput, unsigned long max_idle);
	bool IsAmplifierOn() { return isAmplifierOn; }
	bool IsNowPlaying() { return isNowPlaying; }
	bool IsIdle() { return (isNowPlaying == false) && isAmplifierOn; }
	void SetAmplifierSample(bool musicPlaying);
	void TurnOn();
};

/* ===================================================================
 * AnalogChannel Class
 * Represent a Left+Right Channels to sample
 * ===================================================================
 */
 class AnalogChannel
 {
	private:
	int leftInput;
	int rightInput;
	char *channelName;
	int _ReadInput(int pinL, int pinR);
	
	public:
	int maxLeft;	// the last measure on left channel
	int maxRight;	// the last measure on right channel
	AnalogChannel();
	void Init(int left, int right, char *name);
	bool IsMusicPlaying();
 };

#endif