/* ===================================================================
 * Auto power control of Stereo Amplifier
 * ===================================================================
 * Code to manage status LED
 * ===================================================================
 * By: Zakie Mashiah
 * ===================================================================
 */
#include <WProgram.h>
#include "ledNotifier.h"

LedNotifier::LedNotifier(int red, int green, int blue, unsigned long deepSleep)
{
	redPin = red;
	greenPin = green;
	bluePin = blue;
	off_longTime = deepSleep;
	amplifierOn = musicOn = sourceOn = false;
}

void LedNotifier::openPin(int pin)
{
	pinMode(pin, OUTPUT);
	digitalWrite(pin, false);
}

void LedNotifier::Init(int r, int g, int b)
{
	redPin = r;
	greenPin = g;
	bluePin = b;
	Init();
}

void LedNotifier::Init()
{
	char buff[50];
	
	openPin(redPin);
	openPin(greenPin);
	openPin(bluePin);
	amplifierOn = musicOn = sourceOn = false;
	off_millis = 0;
}

void LedNotifier::AmplifierPlaying() { amplifierOn = true; musicOn = true; }
void LedNotifier::AmplifierOff() { amplifierOn = false; }
void LedNotifier::SetAmpState(bool state) { amplifierOn = state; }


void LedNotifier::SetMusicState(bool state)
{
	// Since music has beats, it causes the LEDs later to flicker between
	// music playing and amplifier idle. This is a bit annoying if you have
	// the LEDs visible really. To avoid that, we want to see the idle is
	// happening for enough time.
	static unsigned long time_music_off = 0UL;
	unsigned long _now = millis();
	
	if (state == false)
	{
		if (time_music_off == 0UL)
			time_music_off = _now;
		else
			if ((_now - time_music_off) > 1000UL) // at least 1000mSec
				musicOn = state;
	}
	else
	{
		time_music_off = 0UL;
		musicOn = state;
		amplifierOn = true;
	}
}


void LedNotifier::SourcePlaying() { sourceOn = true; }
void LedNotifier::SourceOff() { sourceOn = false; }
bool LedNotifier::isSourceOn() { return sourceOn; }
void LedNotifier::SetSourceState(bool state) { sourceOn = state; }


void LedNotifier::Display()
{
	// Define macros in RGB format
	#define LEDMODE_OFF  	0
	#define LEDMODE_RED  	1
	#define LEDMODE_GREEN 	2
	#define LEDMODE_BLUE	4
	#define LEDMODE_UNKNOWN	-1
	int mode = LEDMODE_RED;
	static int last_mode = -1;

	if (amplifierOn)
	{
		if (musicOn)
			mode = LEDMODE_BLUE;
		else
			mode = LEDMODE_GREEN;
	}
	else
	{
		if (sourceOn)
			mode = LEDMODE_GREEN;
		else
			mode = LEDMODE_RED;
	}
	if (mode != last_mode)
	{
        char buff[50];
		
		sprintf(buff, ">>> LED state:\tA=%d\tM=%d\tS=%d", (int)amplifierOn, (int)musicOn, (int)sourceOn);
		Serial.println(buff);
                sprintf(buff, ">>> LED display:\tR=%d\tG=%d\tB=%d\tmode=%d ->", redPin, greenPin, bluePin, mode);
                Serial.print(buff);
		switch (mode)
		{
			case LEDMODE_RED:
				digitalWrite(greenPin, false);
				digitalWrite(bluePin, false);
				digitalWrite(redPin, true);
				Serial.println('R');
				break;
			case LEDMODE_GREEN:
				digitalWrite(redPin, false);
				digitalWrite(bluePin, false);
				digitalWrite(greenPin, true);
				Serial.println('G');
				break;
			case LEDMODE_BLUE:
				digitalWrite(redPin, false);
				digitalWrite(greenPin, false);
				digitalWrite(bluePin, true);
				Serial.println('B');
				break;
                        default:
                                Serial.print("Unknown");
                                break;
		}
	}
    last_mode = mode;
}
